﻿using UnityEngine;
using UnityEngine.SceneManagement;
using UnityEngine.UI;

public class GameManager : SingletonMonoBehaviour<GameManager>
{
    [SerializeField]
    private GameOverScreen[] _gameOverScreens;

    private Rocket _diedRocket;

    public bool GameHasFinished
    {
        get; private set;
    }

    private int _rocketsLost;


    private void Update()
    {
        if (Input.GetKeyDown(KeyCode.Escape))
        {
            SceneManager.LoadScene("StartScene");
        }

        if (Input.GetKeyDown(KeyCode.R))
        {
            Restart();
        }



        if(GameHasFinished && Input.GetKeyDown(KeyCode.KeypadEnter))
        {
            SceneManager.LoadScene("Level01Scene");
        }
    }

    public void RocketHasWon(Rocket rocket)
    {
        if (GameHasFinished) return;

        GameHasFinished = true;

        foreach(GameOverScreen screen in _gameOverScreens)
        {
            if (screen == null) continue;

            screen.RocketHasWon(rocket);
        }
    }

    public void RocketHasDied(Rocket rocket)
    {
        if ((rocket == _diedRocket && _diedRocket != null) && GameSettings.GameMode != GameMode.Coop) return;

        _rocketsLost++;
        _diedRocket = rocket;

        if (_rocketsLost <= 1) return;

        foreach (GameOverScreen screen in _gameOverScreens)
        {
            if (screen == null) continue;

            screen.CoopRocketHasLost(rocket);
        }
    }

    public void Restart()
    {
        SceneManager.LoadScene(SceneManager.GetActiveScene().name);
    }
}
