﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class Planet : MonoBehaviour
{
    protected Dictionary<Collider2D, Rigidbody2D> _objectsInSphereOfInfluence = new Dictionary<Collider2D, Rigidbody2D>();
    private IEnumerator _pullRoutine;

    private void Awake()
    {
        transform.position = new Vector3(transform.position.x, transform.position.y, 0);
    }

    private void OnTriggerEnter2D(Collider2D collider)
    {
        if(_objectsInSphereOfInfluence.ContainsKey(collider))
        {
            Debug.LogErrorFormat("Planet {0} list already contains object {1}, did it not trigger the exit?", name, collider.name);
            return;
        }

        Rigidbody2D rigidbody = collider.GetComponent<Rigidbody2D>();
        if(rigidbody == null)
        {
            return;
        }

        _objectsInSphereOfInfluence.Add(collider, rigidbody);

        if(_pullRoutine == null)
        {
            Debug.LogFormat("Planet {0} starting pull", name);
            StartCoroutine(_pullRoutine = PullRoutine());
        }
    }

    private void OnTriggerExit2D(Collider2D collider)
    {
        if(!_objectsInSphereOfInfluence.ContainsKey(collider))
        {
            return;
        }

        _objectsInSphereOfInfluence.Remove(collider);

        if(_objectsInSphereOfInfluence.Count == 0 && _pullRoutine != null)
        {
            Debug.LogFormat("Planet {0} stopping pull", name);
            StopCoroutine(_pullRoutine);
        }
    }

    private IEnumerator PullRoutine()
    {
        while(true)
        {
            foreach(KeyValuePair<Collider2D, Rigidbody2D> kVP in _objectsInSphereOfInfluence)
            {
                Vector2 dir = (Vector2)transform.position - kVP.Value.position;
                kVP.Value.AddForce(dir.normalized * Time.deltaTime * 10);
            }
            yield return new WaitForFixedUpdate();
        }
    }
}
