﻿using UnityEngine;

public class SingletonMonoBehaviour<T> : MonoBehaviour where T : SingletonMonoBehaviour<T>
{
	private static T _instance;

	public static T Instance
	{
		get
		{
			if(_instance == null)
			{
				Debug.LogErrorFormat("Trying to get Instance of type {0}, but it does not exist!", typeof(T).Name);
				return null;
			}

			return _instance;
		}
	}

	public static bool IsAvailable
	{
		get { return _instance != null; }
	}

	protected void Awake()
	{
		if(_instance != null)
		{
			Debug.LogWarningFormat("A Singleton of type {0} has just been created, but another one already exists!", typeof(T).Name);
			Destroy(this);
		}
		else
		{
			_instance = (T)this;
		}
	}
}
