﻿using System;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.UI;

public class UIButtonsManager : MonoBehaviour
{
    [SerializeField]
    private KeyCode _upKey;
    [SerializeField]
    private KeyCode _downKey;
    [SerializeField]
    private KeyCode _leftKey;
    [SerializeField]
    private KeyCode _rightKey;
    [SerializeField]
    private KeyCode _selectKey;
    [SerializeField]
    private KeyCode _cancelKey;

    [SerializeField]
    private UIButton[] _uiButtons;

    [SerializeField]
    private Text _delayText;
    [SerializeField]
    private Text _actionText;


    [SerializeField]
    private Rocket _rocket;
    [SerializeField]
    private Image _healthBarFill;


    List<Rocket.DelayedAction> _delayedActions = new List<Rocket.DelayedAction>();

    private int _selectedButton = 0;

    private void Start()
    {
        foreach (UIButton button in _uiButtons)
        {
            button.Initialize(_rocket);
        }

        ChangeToButton(_selectedButton);
    }

    /// <summary>
    /// Call before start
    /// </summary>
    public void ChangeRocket(Rocket rocket)
    {
        _rocket = rocket;
    }

    private void ChangeToButton(int id)
    {
        if (id >= _uiButtons.Length || id < 0)
        {
            return;
        }

        _uiButtons[_selectedButton].Deselect();
        _uiButtons[id].Select();
        _selectedButton = id;
    }

    private void DecreaseValue()
    {
        _uiButtons[_selectedButton].DecreaseValue();
    }

    private void IncreaseValue()
    {
        _uiButtons[_selectedButton].IncreaseValue();
    }

    private void TriggerButton()
    {
        _uiButtons[_selectedButton].Trigger();

    }

    private void ResetButton()
    {
        _uiButtons[_selectedButton].Reset();
    }

    private void Update()
    {
        if (GameManager.Instance.GameHasFinished) return;

        if (_delayText != null)
        {
            _delayText.text = "Delay: " + Math.Round(_rocket.DelayTime, 2) + "s";
        }

        _healthBarFill.fillAmount = _rocket.CurrentHealth / _rocket.MaxHealth;

        if (_actionText != null)
        {
            _actionText.text = "Action:\n"; //Update twee keer en verwijderd elkaar
            foreach (Rocket.DelayedAction t in _rocket.DelayedActions)
            {
                _actionText.text += t.Name + " - " + t.ReadableValue + " - " + Math.Round(t.Delay, 2) + "s\n";
            }
        }

        if (Input.GetKeyDown(_downKey))
        {
            ChangeToButton(_selectedButton + 1);
        }
        if (Input.GetKeyDown(_upKey))
        {
            ChangeToButton(_selectedButton - 1);
        }
        if (Input.GetKeyDown(_selectKey))
        {
            TriggerButton();
        }
        if (Input.GetKeyDown(_cancelKey))
        {
            ResetButton();
        }
        if (Input.GetKeyDown(_leftKey))
        {
            DecreaseValue();
        }
        if (Input.GetKeyDown(_rightKey))
        {
            IncreaseValue();
        }
    }
}
